@@ -1,9 +1,7 @@
 use std::path::PathBuf;
 use swc_common::pass::Repeat;
-use swc_ecma_parser::EsConfig;
-use swc_ecma_parser::Syntax;
-use swc_ecma_transforms_optimization::simplify::dce::dce;
-use swc_ecma_transforms_optimization::simplify::expr_simplifier;
+use swc_ecma_parser::{EsConfig, Syntax};
+use swc_ecma_transforms_optimization::simplify::{dce::dce, expr_simplifier};
 use swc_ecma_transforms_testing::test_fixture;
 
 #[testing::fixture("tests/dce/**/input.js")]
