@@ -528,7 +528,7 @@ test!(
         chain!(
             strip(),
             decorators(Default::default()),
-            class_properties(),
+            class_properties(class_properties::Config { loose: false }),
             simplifier(Default::default()),
             es2018(),
             es2017(),
